/* -*- Mode: C; indent-tabs-mode: t; tab-width: 2; c-basic-offset: 2 -*- */
/* GtkTrue - Brings the truth to your desktop!
 * Copyright  1999 Joachim Nilsson <joachim.nilsson@mds.mdh.se>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <popt.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"


int main (int argc, char *argv[])
{
	int         rc;
	char        *message = NULL;
	char        *display = NULL;
	poptContext optCon;
  GtkWidget   *base_window = NULL;
	
	struct poptOption optionsTable[] = {
		{ "message", 'T', POPT_ARG_STRING, &message, 0,
			_("Message to be displayed"), _("Any useful message") },
		{ "version", '\0', POPT_ARG_NONE, NULL, 1,
			_("Prints version information"), NULL},
		{ "compat", '\0', POPT_ARG_NONE, NULL, 2,
			_("Compatible mode"), NULL},
		{ "display", 'd', POPT_ARG_STRING, &display, 3,
			_("Dispay to be used."), _("host.domain:0.0")},
		POPT_AUTOHELP
		{ NULL, 0, 0, NULL, 0, NULL, NULL }
	};
	
	/* Does there exist a /bin/true on this system?
	 */
	if (SYSTEMTRUE)
		{
			whatisthematrix (SYSTEMTRUE);
			/* Linked as true or /bin/true ??
			 * Then simulate true.
			 */
			if (0 == strcmp (SYSTEMTRUE, argv[0]))
				{
					fprintf (stderr, _("Started as system wide truth -> Entering simulation mode.\n"));
					simulate_truth ();
				}
		}
	/* No /bin/true or equivalent detected by configure */
	else
		{
			/*			fprintf (stderr, _("No /bin/true or equivalent detected by configure\n")); */
			simulate_truth ();
		}

  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
  textdomain (PACKAGE);

	optCon = poptGetContext (NULL, argc, argv, optionsTable, 0);
	poptSetOtherOptionHelp (optCon, _("[OPTIONS]"));

	while ( (rc = poptGetNextOpt (optCon)) >= 0)
		{
			switch (rc)
				{
				case 0:
					/* Change the message to be displayed to that of 'message' */
					break;

				case 1:
					/* Display version information, config.h tells us this! :) */
					fprintf (stdout, _("gtrue - GtkTrue ver. %s\n\
Written by Joachim Nilsson <joachim.nilsson@mds.mdh.se>.\n\
\n\
Copyright (C) 1999 Free Software Foundation, Inc.\n\
This is free software; see the source for copying conditions.  There is NO\n\
warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
									 VERSION);
					exit (EXIT_SUCCESS);
					break;

				case 2:
					/* Change to compatible mode. Use /bin/true or equivalent. */
					simulate_truth ();
					break;

				case 3:
					/* Set DISPLAY, but do not change system defaults ... */
					if (0 != setenv ("DISPLAY", display, 0))
						simulate_truth ();
					break;
					
				default:
					/*					fprintf (stderr, _("This is not a Mail User Agent, stupid! Try Mutt instead. :) \n")); */
					poptPrintUsage(optCon, stderr, 0);
					exit (EXIT_FAILURE);
					break;
				}
		}
	
	poptFreeContext(optCon);
	
  /* Running without a DISPLAY set?
   * In that case, let /bin/true take over and discard the GTK interface.
   */
  if (NULL == getenv ("DISPLAY"))
		{
			/*			fprintf (stderr, _("Oups, DISLAY not set!\nUsing system default truth.\n")); */
			take_over ();
		}

	gtk_set_locale ();
  gtk_init (&argc, &argv);

  add_pixmap_directory (PACKAGE_DATA_DIR "/pixmaps");
  add_pixmap_directory (PACKAGE_SOURCE_DIR "/pixmaps");

  /*
   * The following code was added by Glade to create one of each component
   * (except popup menus), just so that you see something after building
   * the project. Delete any components that you don't want shown initially.
   */
  base_window = create_base_window (message);
  gtk_widget_show (base_window);

  gtk_main ();
  return 0;
}

